==> xwidgetsbase-8.7.7.tar.gz: lib/XWidgets/XDD/XDDGenericWithType.dart <==
part of xwidgetbase;

class XDDGenericWithType<T> extends StatefulWidget {
  XDDGenericWithType(
    this.xThemeData, {
    Key? key,
    this.ddColorBTN,
    this.ddColorMenu,
    this.filterItems,
    this.filterValue,
    this.onChangeDD,
    this.hintText,
    this.propToShowInItems,
  }) : super(key: key);
  T? filterValue;
  List<T>? filterItems;
  String? hintText;
  Function(dynamic)? onChangeDD;
  Color? ddColorBTN;
  Color? ddColorMenu;
  String? propToShowInItems;
  ThemeData? xThemeData;
  @override
  _XDDGenericWithTypeState<T> createState() => _XDDGenericWithTypeState<T>();
}

class _XDDGenericWithTypeState<T> extends State<XDDGenericWithType<T>> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(children: [
      Expanded(
          child: Container(
              child: DropdownButtonHideUnderline(
                  child: GFDropdown<T>(
                      hint: Text(widget.hintText ?? "inserisci"),
                      elevation: 8,
                      dropdownButtonColor: widget.xThemeData!.colorScheme.background,
                      padding: const EdgeInsets.all(5),
                      border: BorderSide(width: 1, color: widget.xThemeData!.colorScheme.primary),
                      style: XStyles.xStyTextForTextBase(),
                      iconDisabledColor: widget.xThemeData!.colorScheme.primary,
                      iconEnabledColor: widget.xThemeData!.colorScheme.primary,
                      dropdownColor: widget.ddColorBTN,
                      isExpanded: true,
                      isDense: true,
                      value: widget.filterValue,
                      onTap: () {},
                      onChanged: widget.onChangeDD!,
                      items: widget.filterItems!
                          .map((value) => DropdownMenuItem<T>(
                              value: value,
                              child: Row(mainAxisAlignment: MainAxisAlignment.start, children: [
                                Container(
                                  margin: EdgeInsets.only(top: 3, bottom: 3),
                                  alignment: Alignment.centerLeft,
                                  child: Text(widget.propToShowInItems == null ? " " : (" " + (value as dynamic)[widget.propToShowInItems!]), overflow: TextOverflow.ellipsis, style: XStyles.xStyTextForDescr(XColors.xcolor_ForegroundLight)),
                                )
                              ])))
                          .toList()))))
    ]);
  }
}

==> xwidgetsbase-10.1.7.tar.gz: lib/XWidgets/XDD/XDDGenericWithType.dart <==
part of xwidgetbase;

class XDDGenericWithType<T> extends StatefulWidget {
  XDDGenericWithType(
    this.xThemeData, {
    Key? key,
    this.ddColorBTN,
    this.ddColorMenu,
    this.filterItems,
    this.filterValue,
    this.onChangeDD,
    this.hintText,
    this.propToShowInItems,
  }) : super(key: key);
  T? filterValue;
  List<T>? filterItems;
  String? hintText;
  Function(dynamic)? onChangeDD;
  Color? ddColorBTN;
  Color? ddColorMenu;
  String? propToShowInItems;
  ThemeData? xThemeData;
  @override
  _XDDGenericWithTypeState<T> createState() => _XDDGenericWithTypeState<T>();
}

class _XDDGenericWithTypeState<T> extends State<XDDGenericWithType<T>> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(children: [
      Expanded(
          child: Container(
              child: DropdownButtonHideUnderline(
                  child: GFDropdown<T>(
                      hint: Text(widget.hintText ?? "inserisci"),
                      elevation: 8,
                      dropdownButtonColor: widget.xThemeData!.colorScheme.background,
                      padding: const EdgeInsets.all(5),
                      border: BorderSide(width: 1, color: widget.xThemeData!.colorScheme.primary),
                      style: XStyles.xStyTextForTextBase(),
                      iconDisabledColor: widget.xThemeData!.colorScheme.primary,
                      iconEnabledColor: widget.xThemeData!.colorScheme.primary,
                      dropdownColor: widget.ddColorBTN,
                      isExpanded: true,
                      isDense: true,
                      value: widget.filterValue,
                      onTap: () {},
                      onChanged: widget.onChangeDD!,
                      items: widget.filterItems!
                          .map((value) => DropdownMenuItem<T>(
                              value: value,
                              child: Row(mainAxisAlignment: MainAxisAlignment.start, children: [
                                Container(
                                  margin: EdgeInsets.only(top: 3, bottom: 3),
                                  alignment: Alignment.centerLeft,
                                  child: Text(widget.propToShowInItems == null ? " " : (" " + (value as dynamic)[widget.propToShowInItems!]), overflow: TextOverflow.ellipsis, style: XStyles.xStyTextForDescr(XColors.foregroundLight)),
                                )
                              ])))
                          .toList()))))
    ]);
  }
}
